summaryrefslogtreecommitdiff
path: root/ACE/ace/ACE.h
diff options
context:
space:
mode:
Diffstat (limited to 'ACE/ace/ACE.h')
-rw-r--r--ACE/ace/ACE.h12
1 files changed, 8 insertions, 4 deletions
diff --git a/ACE/ace/ACE.h b/ACE/ace/ACE.h
index c9ccd7352ef..4f65a0cd0b0 100644
--- a/ACE/ace/ACE.h
+++ b/ACE/ace/ACE.h
@@ -54,14 +54,18 @@ class ACE_Handle_Set;
namespace ACE
{
// = ACE version information.
- /// e.g., the "5" in ACE 5.1.12.
+ /// e.g., the "6" in ACE 6.3.4
extern ACE_Export u_int major_version (void);
- /// e.g., the "1" in ACE 5.1.12.
+ /// e.g., the "3" in ACE 6.3.4
extern ACE_Export u_int minor_version (void);
- /// e.g., the "12" in ACE 5.1.12.
- /// Returns 0 for "stable" (non-beta) releases.
+ /// e.g., the "4" in ACE 6.3.4
+ /// Returns 0 for "stable" (non-micro) releases.
+ extern ACE_Export u_int micro_version (void);
+
+ /// e.g., the "4" in ACE 6.3.4
+ /// Returns 0 for "stable" (non-micro) releases.
extern ACE_Export u_int beta_version (void);
// = C++ compiler version information.